CADISHI modules
===============

The following documentation was automatically generated from the docstrings
present in the source code files.

.. toctree::
   :maxdepth: 2

cadishi
-------

.. automodule:: cadishi
   :members:
   :undoc-members:

cadishi.base
------------

.. automodule:: cadishi.base
   :members:
   :undoc-members:

cadishi.io.ascii
----------------

.. automodule:: cadishi.io.ascii
   :members:
   :undoc-members:

cadishi.io.dummy
----------------

.. automodule:: cadishi.io.dummy
   :members:
   :undoc-members:

cadishi.io.hdf5
--------------------

.. automodule:: cadishi.io.hdf5
   :members:
   :undoc-members:

cadishi.io.pickle
-----------------

.. automodule:: cadishi.io.pickel
   :members:
   :undoc-members:

cadishi.dict_util
-----------------

.. automodule:: cadishi.dict_util
   :members:
   :undoc-members:

cadishi.dictfs
--------------

.. automodule:: cadishi.dictfs
   :members:
   :undoc-members:

cadishi.h5pickle
----------------

.. automodule:: cadishi.h5pickle
   :members:
   :undoc-members:

cadishi.util
------------

.. automodule:: cadishi.util
   :members:
   :undoc-members:

cadishi.version
---------------

.. automodule:: cadishi.version
   :members:
   :undoc-members:
